@@ -29,7 +29,7 @@ class HttpStatus:
     HTTP_400_BAD_REQUEST = 400
     HTTP_401_UNAUTHORIZED = 401
     HTTP_402_PAYMENT_REQUIRED = 402
-    HTTP_403_FORBcodeDEN = 403
+    HTTP_403_FORBIDDEN = 403
     HTTP_404_NOT_FOUND = 404
     HTTP_405_METHOD_NOT_ALLOWED = 405
     HTTP_406_NOT_ACCEPTABLE = 406
