@@ -15,7 +15,7 @@ class SoftDeleteCascadeMixin(safedelete_models.SafeDeleteModel):
         if not self.UNIQUE_FIELDS:
             return True
         filters = {f: getattr(self, f) for f in self.UNIQUE_FIELDS}
-        if self.__class__.objects.filter(~Q(pk=self.pk), is_deleted=False, **filters).exists():
+        if self.__class__.objects.filter(is_deleted=False, **filters).filter(~Q(pk=self.pk)).exists():
             data = ', '.join([f'{field_name} {getattr(self, field_name)}' for field_name in self.UNIQUE_FIELDS])
             raise Error(message=f'{data} already exist!', field_name=self.UNIQUE_FIELDS[-1])
 
